// Copyright (c) Project Jupyter Contributors
// Distributed under the terms of the Modified BSD License.
import midi from 'webmidi';
import { IJupyterWidgetRegistry } from '@jupyter-widgets/base';
import * as widgetExports from './widget';
import { MODULE_NAME, MODULE_VERSION } from './version';
import { PromiseDelegate } from '@phosphor/coreutils';
const EXTENSION_ID = '@jupyter-widgets/midicontrols:plugin';
/**
 * The example plugin.
 */
const examplePlugin = {
    id: EXTENSION_ID,
    requires: [IJupyterWidgetRegistry],
    activate: activateWidgetExtension,
    autoStart: true
};
export default examplePlugin;
/**
 * Activate the widget extension.
 */
async function activateWidgetExtension(app, registry) {
    registry.registerWidget({
        name: MODULE_NAME,
        version: MODULE_VERSION,
        exports: widgetExports,
    });
    const midiEnabled = new PromiseDelegate();
    midi.enable(function (err) {
        if (err) {
            midiEnabled.reject(err);
        }
        else {
            midiEnabled.resolve(undefined);
        }
    });
    await midiEnabled.promise;
    if (!(midi.inputs[0] && midi.outputs[0])) {
        throw new Error("Could not find MIDI device");
    }
}
